/*
 * Copyright (c) 1988,1990,1993,1994,2021 by Paul Vixie ("VIXIE")
 * Copyright (c) 2004 by Internet Systems Consortium, Inc. ("ISC")
 * Copyright (c) 1997,2000 by Internet Software Consortium, Inc.
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND VIXIE DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL VIXIE BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include "cron.h"

#if !defined(lint) && !defined(LINT)
static char     rcsid[] = "$Id: job.c,v 1.1 2024-06-09 01:04:19+05:30 Cprogrammer Exp mbhangui $";
#endif

typedef struct _job {
	struct _job    *next;
	const entry    *e;
	const user     *u;
} job;

static job     *jhead = NULL, *jtail = NULL;

void
job_add(const entry *e, const user *u)
{
	job            *j;

	/*- if already on queue, keep going */
	for (j = jhead; j != NULL; j = j->next)
		if (j->e == e && j->u == u)
			return;

	/*- build a job queue element */
	if ((j = (job *) malloc(sizeof (job))) == NULL)
		return;
	j->next = NULL;
	j->e = e;
	j->u = u;

	/*- add it to the tail */
	if (jhead == NULL)
		jhead = j;
	else
		jtail->next = j;
	jtail = j;
}

int
job_runqueue(void)
{
	job            *j, *jn;
	int             run = 0;

	for (j = jhead; j; j = jn) {
		do_command(j->e, j->u);
		jn = j->next;
		free(j);
		run++;
	}
	jhead = jtail = NULL;
	return (run);
}

void
getversion_job_c()
{
	const char *x = rcsid;
	x++;
}

/*
 * $Log: job.c,v $
 * Revision 1.1  2024-06-09 01:04:19+05:30  Cprogrammer
 * Initial revision
 *
 */
